summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorRalf Baechle <ralf@linux-mips.org>2000-06-16 23:00:36 +0000
committerRalf Baechle <ralf@linux-mips.org>2000-06-16 23:00:36 +0000
commit14dd2ec093cfabda3ae7efeeaf0e23c66ebaccc0 (patch)
tree9a9ce5cff6ef92faa6e07a82785b9a6d6838f7e4 /scripts
parent847290510f811c572cc2aa80c1f02a04721410b1 (diff)
Merge with 2.4.0-test1.
Diffstat (limited to 'scripts')
-rw-r--r--scripts/kernel-doc2
-rw-r--r--scripts/mkdep.c10
2 files changed, 6 insertions, 6 deletions
diff --git a/scripts/kernel-doc b/scripts/kernel-doc
index a5370a1ab..f58867de7 100644
--- a/scripts/kernel-doc
+++ b/scripts/kernel-doc
@@ -316,7 +316,7 @@ sub output_sgml {
my $count;
my $id;
- $id = $args{'module'}."-".$args{'function'};
+ $id = "API-".$args{'function'};
$id =~ s/[^A-Za-z0-9]/-/g;
print "<refentry>\n";
diff --git a/scripts/mkdep.c b/scripts/mkdep.c
index aa46a07ba..433fba27c 100644
--- a/scripts/mkdep.c
+++ b/scripts/mkdep.c
@@ -285,8 +285,8 @@ void use_config(const char * name, int len)
*/
#define MAX2(a,b) ((a)>(b)?(a):(b))
#define MIN2(a,b) ((a)<(b)?(a):(b))
-#define MAX6(a,b,c,d,e,f) (MAX2(a,MAX2(b,MAX2(c,MAX2(d,MAX2(e,f))))))
-#define MIN6(a,b,c,d,e,f) (MIN2(a,MIN2(b,MIN2(c,MIN2(d,MIN2(e,f))))))
+#define MAX5(a,b,c,d,e) (MAX2(a,MAX2(b,MAX2(c,MAX2(d,e)))))
+#define MIN5(a,b,c,d,e) (MIN2(a,MIN2(b,MIN2(c,MIN2(d,e)))))
@@ -304,7 +304,7 @@ void use_config(const char * name, int len)
* About 98% of the CPU time is spent here, and most of that is in
* the 'start' paragraph. Because the current characters are
* in a register, the start loop usually eats 4 or 8 characters
* per memory read. The MAX6 and MIN6 tests dispose of most
* input characters with 1 or 2 comparisons.
*/
void state_machine(const char * map, const char * end)
@@ -317,8 +317,8 @@ void state_machine(const char * map, const char * end)
start:
GETNEXT
__start:
- if (current > MAX6('/','\'','"','#','C','_')) goto start;
- if (current < MIN6('/','\'','"','#','C','_')) goto start;
+ if (current > MAX5('/','\'','"','#','C')) goto start;
+ if (current < MIN5('/','\'','"','#','C')) goto start;
CASE('/', slash);
CASE('\'', squote);
CASE('"', dquote);
@@ -304,7 +304,7 @@ void use_config(const char * name, int len)
* the 'start' paragraph. Because the current characters are
* in a register, the start loop usually eats 4 or 8 characters
- * per memory read. The MAX6 and MIN6 tests dispose of most
+ * per memory read. The MAX5 and MIN5 tests dispose of most
* input characters with 1 or 2 comparisons.
*/